@@ -26,10 +26,11 @@ const GObject = imports.gi.GObject;
 const Gst = imports.gi.Gst;
 const GstAudio = imports.gi.GstAudio;
 const Gtk = imports.gi.Gtk;
+const Lang = imports.lang;
+const Mainloop = imports.mainloop;
 
 const _ = imports.gettext.gettext;
 const C_ = imports.gettext.pgettext;
-const Mainloop = imports.mainloop;
 
 const MainWindow = imports.mainWindow;
 const Application = imports.application;
@@ -66,7 +67,7 @@ const WaveForm = new Lang.Class({
         let drawingWidth = 0;
         let drawingHeight = 0;
         this.drawing = Gtk.DrawingArea.new({ height_request: 45,
-                                             width_request: 350,
+                                             width_request: 300,
                                              valign: Gtk.Align.FILL });
         if (this.waveType == WaveType.RECORD) {
             gridWidth = MainWindow.groupGrid.get_allocated_width();
@@ -75,7 +76,9 @@ const WaveForm = new Lang.Class({
             this.drawing.set_property("hexpand",true);
             this._grid.attach(this.drawing, 2, 0, 3, 2);
         } else {
-            this.drawing.set_size_request(350, 45);
+            gridWidth = this._grid.get_allocated_width();
+            gridWidth = gridWidth * 0.70;
+            this.drawing.set_size_request(gridWidth, 45);
             this.drawing.set_property("hexpand",true);
             this._grid.add(this.drawing);
         }
